@@ -5,7 +5,7 @@ Created on Tue May 11 17:41:38 2021
 @author: Berkay
 """
 
-from . import GetStockData,GetFXData
+from . import GetStockData,GetFXData,GetStatData
 
 
 
@@ -29,4 +29,18 @@ def financeData(symbol,stockmarket=None,start=None,end=None):
 def financeFXData(symbol,start=None,end=None):
     return GetFXData(symbol = symbol,
                             start =start,
-                            end = end).GetData()  
\ No newline at end of file
+                            end = end).GetData()  
+
+
+
+def financeStockStat(symbol,stockmarket=None):
+    
+    data_source="yahoo"
+    if data_source != 'yahoo':
+        msg = "Only yahoo available.Please try again next time." 
+        raise NotImplementedError(msg)
+    
+    if data_source == "yahoo":
+        return GetStatData(symbol = symbol,
+                            market = stockmarket
+                            ).GetData()    
\ No newline at end of file
